@@ -11,7 +11,7 @@ from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_true_y, get_visual_info_regressor
 from Accuinsight.modeler.core.sklearnModelType import REGRESSION, CLASSIFICATION
 from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_PARAMS, SELECTED_METRICS, VALUE_ERROR, \
-    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, USER_ID
+    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, USER_ID, RUN_OBJ_NAME
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, \
     set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
@@ -90,10 +90,17 @@ class accuinsight(Common):
         global notebook_info
         notebook_info = get_current_notebook()
 
-    def get_run_meta(self):
+    @staticmethod
+    def get_current_run_meta():
         global run_meta
         return run_meta
 
+    def get_current_run_id(self):
+        try:
+            return self.get_current_run_meta()[RUN_OBJ_NAME]
+        except TypeError or KeyError:
+            return None
+
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
             self.shap_on = model_monitor
