@@ -8,6 +8,7 @@ from collections import OrderedDict
 
 import boto3
 from hdfs3 import HDFileSystem
+from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_or_create_run_directory
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.core.LcConst.LcConst import ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.utils.runs_utils import ProgressPercentage
@@ -43,6 +44,7 @@ class Common(object):
                     secret_key=None,  # aws-s3
                     region=None,  # aws-s3
                     bucket_name=None,  # aws-s3
+                    endpoint_url=None,  # none aws-s3
                     hdfs_uri=None,  # pipeline-hdfs
                     file_path=None,  # common
                     target=None,  # common
@@ -81,19 +83,33 @@ class Common(object):
             self.storage_info_from_set['filePath'] = os.path.join('/', *split_1[1:])
             self.storage_info_from_set['target'] = target
 
-        ### AWS - S3
+        ### S3
         elif bucket_name is not None:
-            storage_type = 's3'
+            ### AWS - S3
+            if endpoint_url is None:
+                storage_type = 's3'
+                self.storage_info_from_set['myAccessKey'] = access_key
+                self.storage_info_from_set['mySecretKey'] = secret_key
+                self.storage_info_from_set['endpoint'] = 's3.' + region + '.amazonaws.com'
+                self.storage_info_from_set['region'] = region
+                self.storage_info_from_set['bucketType'] = 's3'
+                self.storage_info_from_set['bucketName'] = bucket_name
+                self.storage_info_from_set['filePath'] = file_path
+                self.storage_info_from_set['fileName'] = file_path.split('/')[-1]
+                self.storage_info_from_set['target'] = target
 
-            self.storage_info_from_set['myAccessKey'] = access_key
-            self.storage_info_from_set['mySecretKey'] = secret_key
-            self.storage_info_from_set['endpoint'] = 's3.' + region + '.amazonaws.com'
-            self.storage_info_from_set['region'] = region
-            self.storage_info_from_set['bucketType'] = 's3'
-            self.storage_info_from_set['bucketName'] = bucket_name
-            self.storage_info_from_set['filePath'] = file_path
-            self.storage_info_from_set['fileName'] = file_path.split('/')[-1]
-            self.storage_info_from_set['target'] = target
+            ### other - S3
+            else:
+                storage_type = 's3'
+                self.storage_info_from_set['myAccessKey'] = access_key
+                self.storage_info_from_set['mySecretKey'] = secret_key
+                self.storage_info_from_set['endpointUrl'] = endpoint_url
+                self.storage_info_from_set['region'] = region
+                self.storage_info_from_set['bucketType'] = 's3'
+                self.storage_info_from_set['bucketName'] = bucket_name
+                self.storage_info_from_set['filePath'] = file_path
+                self.storage_info_from_set['fileName'] = file_path.split('/')[-1]
+                self.storage_info_from_set['target'] = target
 
         ### Local
         else:
@@ -173,44 +189,79 @@ class Common(object):
 
         ### AWS-S3
         elif 'bucketName' in self.StorageInfo.keys():
-            BUCKET_TYPE = self.StorageInfo['bucketType']
-            BUCKET_NAME = self.StorageInfo['bucketName']
-            FILE_PATH = self.StorageInfo['filePath']
-            FILE_NAME = self.StorageInfo['fileName']
-            # FILE_TYPE = self.StorageInfo['fileType']
-            # FILE_DELIM = self.StorageInfo['fileDelim']
-            ACCESS_KEY = self.StorageInfo['myAccessKey']
-            SECRET_KEY = self.StorageInfo['mySecretKey']
-            REGION = self.StorageInfo['region']
-            URL = self.StorageInfo['endpoint']
+            if not 'endpointUrl' in self.StorageInfo.keys():
+                BUCKET_TYPE = self.StorageInfo['bucketType']
+                BUCKET_NAME = self.StorageInfo['bucketName']
+                FILE_PATH = self.StorageInfo['filePath']
+                FILE_NAME = self.StorageInfo['fileName']
+                # FILE_TYPE = self.StorageInfo['fileType']
+                # FILE_DELIM = self.StorageInfo['fileDelim']
+                ACCESS_KEY = self.StorageInfo['myAccessKey']
+                SECRET_KEY = self.StorageInfo['mySecretKey']
+                REGION = self.StorageInfo['region']
+                URL = self.StorageInfo['endpoint']
+                ## path for saving data
+                save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_aws')
+                if not os.path.exists(save_dir):
+                    os.mkdir(save_dir)
+                else:
+                    pass
+
+                save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') \
+                                 + '.' + FILE_NAME.split('.')[1]
+                self.save_path = os.path.join(save_dir, save_file_name)
+
+                # endpoint
+                pre_url = 'https://' + BUCKET_NAME + '.' + URL
+                self.endpoint = os.path.join(pre_url, FILE_PATH)
+
+                client = boto3.client(BUCKET_TYPE,
+                                      aws_access_key_id=ACCESS_KEY,
+                                      aws_secret_access_key=SECRET_KEY,
+                                      region_name=REGION)
+
+                transfer = boto3.s3.transfer.S3Transfer(client)
+
+                progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
+
+                sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+                transfer.download_file(BUCKET_NAME, FILE_PATH, self.save_path, callback=progress)
+                logging.info(self.save_path)
 
-            ## path for saving data
-            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_aws')
-            if not os.path.exists(save_dir):
-                os.mkdir(save_dir)
             else:
-                pass
+                BUCKET_TYPE = self.StorageInfo['bucketType']
+                BUCKET_NAME = self.StorageInfo['bucketName']
+                FILE_PATH = self.StorageInfo['filePath']
+                FILE_NAME = self.StorageInfo['fileName']
+                ACCESS_KEY = self.StorageInfo['myAccessKey']
+                SECRET_KEY = self.StorageInfo['mySecretKey']
+                REGION = self.StorageInfo['region']
+                ENDPOINT_URL = self.StorageInfo['endpointUrl']
+                ## path for saving data
+                save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_other')
+                if not os.path.exists(save_dir):
+                    os.mkdir(save_dir)
+                else:
+                    pass
 
-            save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '')\
-                                  + '.' + FILE_NAME.split('.')[1]
-            self.save_path = os.path.join(save_dir, save_file_name)
+                save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '')\
+                                      + '.' + FILE_NAME.split('.')[1]
+                self.save_path = os.path.join(save_dir, save_file_name)
 
-            # endpoint
-            pre_url = 'https://' + BUCKET_NAME + '.' + URL
-            self.endpoint = os.path.join(pre_url, FILE_PATH)
+                # endpoint
+                client = boto3.client(BUCKET_TYPE,
+                                      aws_access_key_id=ACCESS_KEY,
+                                      aws_secret_access_key=SECRET_KEY,
+                                      region_name=REGION,
+                                      endpoint_url=ENDPOINT_URL)
 
-            client = boto3.client(BUCKET_TYPE,
-                                  aws_access_key_id=ACCESS_KEY,
-                                  aws_secret_access_key=SECRET_KEY,
-                                  region_name=REGION)
+                transfer = boto3.s3.transfer.S3Transfer(client)
 
-            transfer = boto3.s3.transfer.S3Transfer(client)
+                progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
 
-            progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
-
-            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-            transfer.download_file(BUCKET_NAME, FILE_PATH, self.save_path, callback=progress)
-            logging.info(self.save_path)
+                sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+                transfer.download_file(BUCKET_NAME, FILE_PATH, self.save_path, callback=progress)
+                logging.info(self.save_path)
 
         ### Local
         else:
