@@ -10,8 +10,7 @@ from keras.callbacks import CSVLogger
 from Accuinsight.modeler.core import func, path, get
 from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.LcConst import LcConst
-from Accuinsight.modeler.core.LcConst.LcConst import RUN_NAME_KERAS, RUN_OBJ_NAME, RUN_MODEL_JSON_PATH, \
-    RUN_MODEL_SHAP_JSON_PATH, RUN_MODEL_VISUAL_JSON_PATH, SELECTED_METRICS, USER_ID
+from Accuinsight.modeler.core.LcConst.LcConst import RUN_NAME_KERAS, RUN_OBJ_NAME
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_visual_info_regressor
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, set_model_json_path, \
     set_visual_csv_path, set_visual_json_path, set_best_model_h5_path, set_best_model_json_path, \
@@ -138,7 +137,7 @@ class accuinsight(Common):
                 self.model_summary['model_type'] = get.model_type(self.model)
 
                 if user_id is not None:
-                    self.model_summary[USER_ID] = user_id
+                    self.model_summary['user_id'] = user_id
 
                 if hasattr(self.model.loss, 'get_config'):
                     self.model_summary['loss_function'] = self.model.loss.get_config()['name']
@@ -235,11 +234,11 @@ class accuinsight(Common):
                 
                 end = get_time.now()
                 self.model_summary['time_delta'] = str(end - start)
-                self.model_summary[SELECTED_METRICS] = {self.monitor: self.best}
+                self.model_summary['selected_metrics'] = {self.monitor: self.best}
             
                 # path for model_info.json
                 set_model_json_path(self.dict_path['model_json'])
-                model_json_full_path = self.dict_path[RUN_MODEL_JSON_PATH]
+                model_json_full_path = self.dict_path['model_json_full']
             
                 with open(model_json_full_path, 'w', encoding='utf-8') as save_file:
                     json.dump(self.model_summary, save_file, indent="\t")
@@ -290,7 +289,7 @@ class accuinsight(Common):
 
                 # path for visual.json
                 path_for_setting_visual_json = self.dict_path['visual_json']
-                visual_json_full_path = self.dict_path[RUN_MODEL_VISUAL_JSON_PATH]
+                visual_json_full_path = self.dict_path['visual_json_full']
                 set_visual_json_path(path_for_setting_visual_json)
 
                 # classification
@@ -324,7 +323,7 @@ class accuinsight(Common):
                     self.dict_path = path.get_file_path(self.model, usedFramework='keras')
 
                     # path for shap.json
-                    shap_json_full_path = self.dict_path[RUN_MODEL_SHAP_JSON_PATH]
+                    shap_json_full_path = self.dict_path['shap_json_full']
                     set_shap_json_path(self.dict_path['shap_json'])
 
                     with open(shap_json_full_path, 'w', encoding='utf-8') as save_file:
