@@ -10,7 +10,6 @@ from Accuinsight.modeler.protos import skapi_pb2
 from Accuinsight.modeler.utils.proto_json_utils import parse_dict
 from Accuinsight.modeler.utils.string_utils import strip_suffix
 from Accuinsight.modeler.exceptions import ModelerException, RestException
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, RUN_MODEL_SHAP_JSON_PATH
 
 RESOURCE_DOES_NOT_EXIST = 'RESOURCE_DOES_NOT_EXIST'
@@ -189,11 +188,11 @@ def _make_parameter_data(json_body):
     json_body['parameter'] = parameter
     return json_body
 
-def _make_feature_data(json_body):
+
+def _make_feature_data(json_body, run_info_json):
     json_body['feature'] = {}
     json_body['feature']['importance'] = {}
 
-    run_info_json = get_current_run()
     run_result_path = run_info_json[RUN_RESULT_PATH]
 
     #json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
@@ -210,13 +209,13 @@ def _make_feature_data(json_body):
     return json_body
 
 
-def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
+def call_endpoint(host_creds, endpoint, method, json_body, response_proto, current_run_meta):
     # Cover json String to json dictionary, to pass to requests
     if json_body:
         json_body = json.loads(json_body)
         json_body = _make_metrics_data(json_body)
         json_body = _make_parameter_data(json_body)
-        json_body = _make_feature_data(json_body)
+        json_body = _make_feature_data(json_body, current_run_meta)
     if method == 'GET':
         response = http_request(
             host_creds=host_creds, endpoint=endpoint, method=method, params=json_body)
